@@ -10,7 +10,7 @@ def setup_arguments(parser):
                          help='Wait for Pilot boot message and display after reboot')
   parser.add_argument('--source', '-c', default=None, dest='source',
                       help='Download Sourcecode only')
-  parser.add_argument('--regnode', '-n', dest='regnode', action='store_true',
+  parser.add_argument('--regnode', dest='regnode', action='store_true',
                       help='Register node')
   #parser.add_argument('--reset', '-r', default=None, action='store_const', const='reset', dest='reset',
   #                    help='Resets the Pilot Mainboard')
@@ -25,6 +25,9 @@ def reset_arguments(parser):
   parser.add_argument('--wait_bootmsg', '-w', dest='wait_bootmsg', action='store_true',
                          help='Wait for Pilot boot message and display after reboot')
 
+def remoteit_arguments(parser):
+  parser.add_argument('list', help='List remote.it devices (you need remote.it credentials in the ~/.remoteit/credentials file)')
+
 def module_arguments(parser):
   parser.add_argument('module', metavar='N', type=int,
                     help='module number')
